Changelog
---------

0.0.10 (2016-10-20)
~~~~~~~~~~~~~~~~~~~

- Reworks the datamodel to include a period linked to the occasion/bookings.
  [href]

0.0.9 (2016-10-17)
~~~~~~~~~~~~~~~~~~~

- Improves the performance of the used_tags method.
  [href]

0.0.8 (2016-10-14)
~~~~~~~~~~~~~~~~~~~

- Adds the ability to filter the activites by one or many owners.
  [href]

- Adds the ability to filter the activites by age ranges.
  [href]

0.0.7 (2016-10-10)
~~~~~~~~~~~~~~~~~~~

- Adds the ability to filter activites by the duration of their occasions.
  [href]

- Adds a db constraint ensuring that an occasion always starts before it ends.
  [href]

- Adds an archived state to occasions.
  [href]

0.0.6 (2016-10-06)
~~~~~~~~~~~~~~~~~~~

- Adds a reporter column to activites.
  [href]

0.0.5 (2016-10-04)
~~~~~~~~~~~~~~~~~~~

- Occasions and bookings can no longer be orphaned.
  [href]

- Location is now optional.
  [href]

- Adds an occasion collection.
  [href]

0.0.4 (2016-10-03)
~~~~~~~~~~~~~~~~~~~

- Overhauls the occasion model.
  [href]

0.0.3 (2016-09-29)
~~~~~~~~~~~~~~~~~~~

- Adds the ability to directly access the user object from the activity.
  [href]

0.0.2 (2016-09-26)
~~~~~~~~~~~~~~~~~~~

- Adds the ability to override the query base on a subclass.
  [href]

- Adds the ability to filter the collection by state.
  [href]

- Adds the ability to get the set of used activity tags.
  [href]

0.0.1 (2016-09-22)
~~~~~~~~~~~~~~~~~~~

- Initial Release
